@@ -261,7 +261,8 @@ export default class Buffer {
 
       // We mark the start of each line, which happens directly after this newline char
       // unless this is the last char.
-      if (last < len) {
+      // When manually adding multi-line content (such as a comment), `line` will be `undefined`.
+      if (last < len && line !== undefined) {
         this._mark(++line, 0, identifierName, filename);
       }
       i = str.indexOf("\n", last);
