@@ -66,6 +66,19 @@ export function ExportNamespaceSpecifier(
   this.print(node.exported, node);
 }
 
+export function _printAssertions(
+  this: Printer,
+  node: Extract<t.Node, { assertions?: t.ImportAttribute[] }>,
+) {
+  this.word("assert");
+  this.space();
+  this.token("{");
+  this.space();
+  this.printList(node.assertions, node);
+  this.space();
+  this.token("}");
+}
+
 export function ExportAllDeclaration(
   this: Printer,
   node: t.ExportAllDeclaration | t.DeclareExportAllDeclaration,
@@ -82,13 +95,10 @@ export function ExportAllDeclaration(
   this.space();
   // @ts-expect-error Fixme: assertions is not defined in DeclareExportAllDeclaration
   if (node.assertions?.length) {
-    this.ensureNoLineTerminator(() => {
-      this.print(node.source, node);
-      this.space();
-      this.word("assert");
-    });
+    this.print(node.source, node, true);
+    this.space();
     // @ts-expect-error Fixme: assertions is not defined in DeclareExportAllDeclaration
-    this.printAssertions(node);
+    this._printAssertions(node);
   } else {
     this.print(node.source, node);
   }
@@ -157,12 +167,9 @@ export function ExportNamedDeclaration(
       this.word("from");
       this.space();
       if (node.assertions?.length) {
-        this.ensureNoLineTerminator(() => {
-          this.print(node.source, node);
-          this.space();
-          this.word("assert");
-        });
-        this.printAssertions(node);
+        this.print(node.source, node, true);
+        this.space();
+        this._printAssertions(node);
       } else {
         this.print(node.source, node);
       }
@@ -186,7 +193,7 @@ export function ExportDefaultDeclaration(
   }
 
   this.word("export");
-  this.printInnerComments(node);
+  this.noIndentInnerCommentsHere();
   this.space();
   this.word("default");
   this.space();
@@ -201,11 +208,11 @@ export function ImportDeclaration(this: Printer, node: t.ImportDeclaration) {
 
   const isTypeKind = node.importKind === "type" || node.importKind === "typeof";
   if (isTypeKind) {
-    this.printInnerComments(node, false);
+    this.noIndentInnerCommentsHere();
     this.word(node.importKind);
     this.space();
   } else if (node.module) {
-    this.printInnerComments(node, false);
+    this.noIndentInnerCommentsHere();
     this.word("module");
     this.space();
   }
@@ -246,11 +253,8 @@ export function ImportDeclaration(this: Printer, node: t.ImportDeclaration) {
 
   if (node.assertions?.length) {
     this.print(node.source, node, true);
-    this.ensureNoLineTerminator(() => {
-      this.space();
-      this.word("assert");
-    });
-    this.printAssertions(node);
+    this.space();
+    this._printAssertions(node);
   } else {
     this.print(node.source, node);
   }
