@@ -7,6 +7,7 @@ import {
   isStatement,
   isClassBody,
   isTSInterfaceBody,
+  isTSEnumDeclaration,
 } from "@babel/types";
 import type {
   RecordAndTuplePluginOptions,
@@ -35,9 +36,15 @@ const enum COMMENT_TYPE {
 
 const enum COMMENT_SKIP_NEWLINE {
   DEFAULT,
-  SKIP_ALL,
-  SKIP_LEADING,
-  SKIP_TRAILING,
+  ALL,
+  LEADING,
+  TRAILING,
+}
+
+const enum PRINT_COMMENT_HINT {
+  SKIP,
+  ALLOW,
+  DEFER,
 }
 
 export type Format = {
@@ -637,7 +644,10 @@ class Printer {
     } else {
       shouldPrintParens = needsParens(node, parent, this._printStack);
     }
-    if (shouldPrintParens) this.token("(");
+    if (shouldPrintParens) {
+      this.token("(");
+      this._endsWithInnerRaw = false;
+    }
 
     this._lastCommentLine = 0;
 
@@ -903,48 +913,50 @@ class Printer {
     }
   }
 
-  // Returns `true` if the comment cannot be printed in this position due to
+  // Returns `PRINT_COMMENT_HINT.DEFER` if the comment cannot be printed in this position due to
   // line terminators, signaling that the print comments loop can stop and
-  // resume printing comments at the next posisble position. This happens when
+  // resume printing comments at the next possible position. This happens when
   // printing inner comments, since if we have an inner comment with a multiline
   // there is at least one inner position where line terminators are allowed.
-  _printComment(
-    comment: t.Comment,
-    skipNewLines: COMMENT_SKIP_NEWLINE,
-  ): boolean {
+  _shouldPrintComment(comment: t.Comment): PRINT_COMMENT_HINT {
     // Some plugins (such as flow-strip-types) use this to mark comments as removed using the AST-root 'comments' property,
     // where they can't manually mutate the AST node comment lists.
-    if (comment.ignore) return false;
+    if (comment.ignore) return PRINT_COMMENT_HINT.SKIP;
 
-    if (this._printedComments.has(comment)) return false;
-
-    const noLineTerminator = this._noLineTerminator;
+    if (this._printedComments.has(comment)) return PRINT_COMMENT_HINT.SKIP;
 
     if (
-      noLineTerminator &&
+      this._noLineTerminator &&
       (HAS_NEWLINE.test(comment.value) ||
         HAS_BlOCK_COMMENT_END.test(comment.value))
     ) {
-      return true;
+      return PRINT_COMMENT_HINT.DEFER;
     }
 
-    if (!this.format.shouldPrintComment(comment.value)) return false;
-
     this._printedComments.add(comment);
 
+    if (!this.format.shouldPrintComment(comment.value)) {
+      return PRINT_COMMENT_HINT.SKIP;
+    }
+
+    return PRINT_COMMENT_HINT.ALLOW;
+  }
+
+  _printComment(comment: t.Comment, skipNewLines: COMMENT_SKIP_NEWLINE) {
+    const noLineTerminator = this._noLineTerminator;
     const isBlockComment = comment.type === "CommentBlock";
 
     // Add a newline before and after a block comment, unless explicitly
     // disallowed
     const printNewLines =
       isBlockComment &&
-      skipNewLines !== COMMENT_SKIP_NEWLINE.SKIP_ALL &&
+      skipNewLines !== COMMENT_SKIP_NEWLINE.ALL &&
       !this._noLineTerminator;
 
     if (
       printNewLines &&
       this._buf.hasContent() &&
-      skipNewLines !== COMMENT_SKIP_NEWLINE.SKIP_LEADING
+      skipNewLines !== COMMENT_SKIP_NEWLINE.LEADING
     ) {
       this.newline(1);
     }
@@ -996,11 +1008,9 @@ class Printer {
       this.newline(1, true);
     }
 
-    if (printNewLines && skipNewLines !== COMMENT_SKIP_NEWLINE.SKIP_TRAILING) {
+    if (printNewLines && skipNewLines !== COMMENT_SKIP_NEWLINE.TRAILING) {
       this.newline(1);
     }
-
-    return false;
   }
 
   _printComments(
@@ -1025,8 +1035,12 @@ class Printer {
     for (let i = 0; i < len; i++) {
       const comment = comments[i];
 
-      const printed = this._printedComments.has(comment);
-      if (hasLoc && comment.loc && !printed) {
+      const shouldPrint = this._shouldPrintComment(comment);
+      if (shouldPrint === PRINT_COMMENT_HINT.DEFER) {
+        hasLoc = false;
+        break;
+      }
+      if (hasLoc && comment.loc && shouldPrint === PRINT_COMMENT_HINT.ALLOW) {
         const commentStartLine = comment.loc.start.line;
         const commentEndLine = comment.loc.end.line;
         if (type === COMMENT_TYPE.LEADING) {
@@ -1047,7 +1061,7 @@ class Printer {
           lastLine = commentEndLine;
 
           maybeNewline(offset);
-          this._printComment(comment, COMMENT_SKIP_NEWLINE.SKIP_ALL);
+          this._printComment(comment, COMMENT_SKIP_NEWLINE.ALL);
 
           if (i + 1 === len) {
             maybeNewline(
@@ -1061,7 +1075,7 @@ class Printer {
           lastLine = commentEndLine;
 
           maybeNewline(offset);
-          if (this._printComment(comment, COMMENT_SKIP_NEWLINE.SKIP_ALL)) break;
+          this._printComment(comment, COMMENT_SKIP_NEWLINE.ALL);
 
           if (i + 1 === len) {
             maybeNewline(Math.min(1, nodeEndLine - lastLine)); // TODO: Improve here when inner comments processing is stronger
@@ -1073,12 +1087,13 @@ class Printer {
           lastLine = commentEndLine;
 
           maybeNewline(offset);
-          this._printComment(comment, COMMENT_SKIP_NEWLINE.SKIP_ALL);
+          this._printComment(comment, COMMENT_SKIP_NEWLINE.ALL);
         }
       } else {
         hasLoc = false;
-
-        if (printed) continue;
+        if (shouldPrint !== PRINT_COMMENT_HINT.ALLOW) {
+          continue;
+        }
 
         if (len === 1) {
           const singleLine = comment.loc
@@ -1089,20 +1104,19 @@ class Printer {
             singleLine &&
             !isStatement(node) &&
             !isClassBody(parent) &&
-            !isTSInterfaceBody(parent);
+            !isTSInterfaceBody(parent) &&
+            !isTSEnumDeclaration(parent);
 
           if (type === COMMENT_TYPE.LEADING) {
             this._printComment(
               comment,
               (shouldSkipNewline && node.type !== "ObjectExpression") ||
                 (singleLine && isFunction(parent, { body: node }))
-                ? COMMENT_SKIP_NEWLINE.SKIP_ALL
+                ? COMMENT_SKIP_NEWLINE.ALL
                 : COMMENT_SKIP_NEWLINE.DEFAULT,
             );
           } else if (shouldSkipNewline && type === COMMENT_TYPE.TRAILING) {
-            if (this._printComment(comment, COMMENT_SKIP_NEWLINE.SKIP_ALL)) {
-              break;
-            }
+            this._printComment(comment, COMMENT_SKIP_NEWLINE.ALL);
           } else {
             this._printComment(comment, COMMENT_SKIP_NEWLINE.DEFAULT);
           }
@@ -1117,15 +1131,14 @@ class Printer {
           //   /*:: b: ?string*/
           // }
 
-          const skippedDueToNewline = this._printComment(
+          this._printComment(
             comment,
             i === 0
-              ? COMMENT_SKIP_NEWLINE.SKIP_LEADING
+              ? COMMENT_SKIP_NEWLINE.LEADING
               : i === len - 1
-              ? COMMENT_SKIP_NEWLINE.SKIP_TRAILING
+              ? COMMENT_SKIP_NEWLINE.TRAILING
               : COMMENT_SKIP_NEWLINE.DEFAULT,
           );
-          if (skippedDueToNewline) break;
         } else {
           this._printComment(comment, COMMENT_SKIP_NEWLINE.DEFAULT);
         }
