@@ -14,6 +14,7 @@ export type LValAncestor =
         | "ImportSpecifier"
         | "ImportNamespaceSpecifier"
         | "ImportDefaultSpecifier"
+        | "ParenthesizedExpression"
         | "ObjectPattern"
         | "RestElement"
         | "VariableDeclarator";
@@ -32,6 +33,8 @@ export default {
     "Can not use 'await' as identifier inside a static block.",
   AwaitExpressionFormalParameter:
     "'await' is not allowed in async function parameters.",
+  AwaitInUsingBinding:
+    "'await' is not allowed to be used as a name in 'using' declarations.",
   AwaitNotInAsyncContext:
     "'await' is only allowed within async functions and at the top levels of modules.",
   AwaitNotInAsyncFunction: "'await' is only allowed within async functions.",
