@@ -29,7 +29,7 @@ import { NodeUtils, type Undone } from "./node";
 import {
   type BindingTypes,
   BIND_NONE,
-  BIND_SCOPE_LEXICAL,
+  BIND_FLAGS_NO_LET_IN_LEXICAL,
 } from "../util/scopeflags";
 import type { ExpressionErrors } from "./util";
 import { Errors, type LValAncestor } from "../parse-error";
@@ -560,10 +560,6 @@ export default abstract class LValParser extends NodeUtils {
    *        `checkLVal` will add checked identifier name to `checkClashes` It is
    *        used in tracking duplicates in function parameter lists. If it is
    *        false, `checkLVal` will skip duplicate checks
-   * @param options.allowingSloppyLetBinding
-   *        Whether an identifier named "let" should be allowed in sloppy mode.
-   *        Defaults to `true` unless lexical scope its being used. This property
-   *        is only relevant if the parser's state is in sloppy mode.
    * @param options.strictModeChanged
    *        Whether an identifier has been parsed in a sloppy context but should
    *        be reinterpreted as strict-mode. e.g. `(arguments) => { "use strict "}`
@@ -579,14 +575,12 @@ export default abstract class LValParser extends NodeUtils {
       binding = BIND_NONE,
       checkClashes = false,
       strictModeChanged = false,
-      allowingSloppyLetBinding = !(binding & BIND_SCOPE_LEXICAL),
       hasParenthesizedAncestor = false,
     }: {
       in: LValAncestor;
       binding?: BindingTypes;
       checkClashes?: Set<string> | false;
       strictModeChanged?: boolean;
-      allowingSloppyLetBinding?: boolean;
       hasParenthesizedAncestor?: boolean;
     },
   ): void {
@@ -604,12 +598,11 @@ export default abstract class LValParser extends NodeUtils {
       return;
     }
 
-    if (expression.type === "Identifier") {
+    if (type === "Identifier") {
       this.checkIdentifier(
         expression as Identifier,
         binding,
         strictModeChanged,
-        allowingSloppyLetBinding,
       );
 
       const { name } = expression as Identifier;
@@ -626,7 +619,7 @@ export default abstract class LValParser extends NodeUtils {
     }
 
     const validity = this.isValidLVal(
-      expression.type,
+      type,
       !(hasParenthesizedAncestor || expression.extra?.parenthesized) &&
         ancestor.type === "AssignmentExpression",
       binding,
@@ -637,13 +630,7 @@ export default abstract class LValParser extends NodeUtils {
       const ParseErrorClass =
         binding === BIND_NONE ? Errors.InvalidLhs : Errors.InvalidLhsBinding;
 
-      this.raise(ParseErrorClass, {
-        at: expression,
-        ancestor:
-          ancestor.type === "UpdateExpression"
-            ? { type: "UpdateExpression", prefix: ancestor.prefix }
-            : { type: ancestor.type },
-      });
+      this.raise(ParseErrorClass, { at: expression, ancestor });
       return;
     }
 
@@ -651,21 +638,19 @@ export default abstract class LValParser extends NodeUtils {
       ? validity
       : [validity, type === "ParenthesizedExpression"];
     const nextAncestor =
-      expression.type === "ArrayPattern" ||
-      expression.type === "ObjectPattern" ||
-      expression.type === "ParenthesizedExpression"
-        ? expression
+      type === "ArrayPattern" ||
+      type === "ObjectPattern" ||
+      type === "ParenthesizedExpression"
+        ? ({ type } as const)
         : ancestor;
 
     // @ts-expect-error key may not index expression.
     for (const child of [].concat(expression[key])) {
       if (child) {
         this.checkLVal(child, {
-          // @ts-expect-error: refine types
           in: nextAncestor,
           binding,
           checkClashes,
-          allowingSloppyLetBinding,
           strictModeChanged,
           hasParenthesizedAncestor: isParenthesizedExpression,
         });
@@ -677,7 +662,6 @@ export default abstract class LValParser extends NodeUtils {
     at: Identifier,
     bindingType: BindingTypes,
     strictModeChanged: boolean = false,
-    allowLetBinding: boolean = !(bindingType & BIND_SCOPE_LEXICAL),
   ) {
     if (
       this.state.strict &&
@@ -695,7 +679,7 @@ export default abstract class LValParser extends NodeUtils {
       }
     }
 
-    if (!allowLetBinding && at.name === "let") {
+    if (bindingType & BIND_FLAGS_NO_LET_IN_LEXICAL && at.name === "let") {
       this.raise(Errors.LetInLexicalBinding, { at });
     }
 
