@@ -29,22 +29,22 @@ const bContext = foo['bContext'];
 
 expect(foo.a).toBe(2);
 expect(foo.b).toBe(2);
-expect(aContext.access.get.call(foo)).toBe(2);
-expect(bContext.access.get.call(foo)).toBe(2);
 foo.value = 123;
 expect(foo.a).toBe(124);
 expect(foo.b).toBe(124);
-expect(aContext.access.get.call(foo)).toBe(124);
-expect(bContext.access.get.call(foo)).toBe(124);
 
 expect(aContext.name).toBe('a');
 expect(aContext.kind).toBe('getter');
-expect(aContext.static).toBe(false);
-expect(aContext.private).toBe(false);
+expect(aContext.isStatic).toBe(false);
+expect(aContext.isPrivate).toBe(false);
 expect(typeof aContext.addInitializer).toBe('function');
+expect(typeof aContext.setMetadata).toBe('function');
+expect(typeof aContext.getMetadata).toBe('function');
 
 expect(bContext.name).toBe('b');
 expect(bContext.kind).toBe('getter');
-expect(bContext.static).toBe(false);
-expect(bContext.private).toBe(false);
+expect(bContext.isStatic).toBe(false);
+expect(bContext.isPrivate).toBe(false);
 expect(typeof bContext.addInitializer).toBe('function');
+expect(typeof bContext.setMetadata).toBe('function');
+expect(typeof bContext.getMetadata).toBe('function');
