@@ -27,7 +27,7 @@ function _get_b2() {
   return _get_b(this);
 }
 (() => {
-  [_init_a, _get_a, _set_a, _init_b, _get_b, _set_b, _initStatic] = babelHelpers.applyDecs2203(Foo, [[dec, 6, "a", function () {
+  [_init_a, _get_a, _set_a, _init_b, _get_b, _set_b, _initStatic] = babelHelpers.applyDecs2203R(Foo, [[dec, 6, "a", function () {
     return babelHelpers.classStaticPrivateFieldSpecGet(this, Foo, _A);
   }, function (value) {
     babelHelpers.classStaticPrivateFieldSpecSet(this, Foo, _A, value);
@@ -35,7 +35,7 @@ function _get_b2() {
     return babelHelpers.classStaticPrivateFieldSpecGet(this, Foo, _B);
   }, function (value) {
     babelHelpers.classStaticPrivateFieldSpecSet(this, Foo, _B, value);
-  }]], []);
+  }]], []).e;
   _initStatic(Foo);
 })();
 var _A = {
