@@ -2,9 +2,9 @@ var _call_x, _initProto;
 const dec = () => {};
 class Foo extends Bar {
   static {
-    [_call_x, _initProto] = babelHelpers.applyDecs2203(this, [[dec, 3, "x", function () {
+    [_call_x, _initProto] = babelHelpers.applyDecs2203R(this, [[dec, 3, "x", function () {
       return Bar.prototype.foo.call(this);
-    }]], []);
+    }]], []).e;
   }
   constructor(...args) {
     super(...args);
