@@ -3,9 +3,9 @@ const dec1 = () => {};
 const dec2 = () => {};
 let _Bar;
 class Bar {}
-[_Bar, _initClass] = babelHelpers.applyDecs2203(Bar, [], [dec1]);
+[_Bar, _initClass] = babelHelpers.applyDecs2203R(Bar, [], [dec1]).c;
 _initClass();
 let _Foo;
 class Foo extends _Bar {}
-[_Foo, _initClass2] = babelHelpers.applyDecs2203(Foo, [], [dec2]);
+[_Foo, _initClass2] = babelHelpers.applyDecs2203R(Foo, [], [dec2]).c;
 _initClass2();
