@@ -4,7 +4,7 @@ _computedKey = getKeyI();
 _computedKey2 = getKeyJ();
 class Foo {
   static {
-    [_initProto] = babelHelpers.applyDecs2203(this, [[dec, 2, _computedKey], [dec, 2, _computedKey2]], []);
+    [_initProto] = babelHelpers.applyDecs2203R(this, [[dec, 2, _computedKey], [dec, 2, _computedKey2]], []).e;
   }
   constructor(...args) {
     _initProto(this);
