@@ -13,9 +13,9 @@ var _a = {
   set: void 0
 };
 (() => {
-  [_call_a, _initStatic] = babelHelpers.applyDecs2203(Foo, [[dec, 8, "a", function () {
+  [_call_a, _initStatic] = babelHelpers.applyDecs2203R(Foo, [[dec, 8, "a", function () {
     return this.value;
-  }]], []);
+  }]], []).e;
   _initStatic(Foo);
 })();
 babelHelpers.defineProperty(Foo, "value", 1);
