@@ -2,11 +2,11 @@ var _call_a, _call_a2, _initStatic;
 const dec = () => {};
 class Foo {
   static {
-    [_call_a, _call_a2, _initStatic] = babelHelpers.applyDecs2203(this, [[dec, 8, "a", function () {
+    [_call_a, _call_a2, _initStatic] = babelHelpers.applyDecs2203R(this, [[dec, 8, "a", function () {
       return this.value;
     }], [dec, 9, "a", function (v) {
       this.value = v;
-    }]], []);
+    }]], []).e;
     _initStatic(this);
   }
   static value = 1;
