@@ -6,9 +6,9 @@ class Foo {
   }
 }
 (() => {
-  [_call_a, _initStatic] = babelHelpers.applyDecs2203(Foo, [[dec, 7, "a", function () {
+  [_call_a, _initStatic] = babelHelpers.applyDecs2203R(Foo, [[dec, 7, "a", function () {
     return this.value;
-  }]], []);
+  }]], []).e;
   _initStatic(Foo);
 })();
 var _a = {
