@@ -11,7 +11,10 @@ _dec7 = arbitrary + expr;
 _dec8 = array[expr];
 class Foo {
   static {
-    [_initProto, _Foo, _initClass] = babelHelpers.applyDecs2203(this, [[[dec, _dec5, _dec6, _dec7, _dec8], 2, "method"]], [dec, _dec, _dec2, _dec3, _dec4]);
+    ({
+      e: [_initProto],
+      c: [_Foo, _initClass]
+    } = babelHelpers.applyDecs2203R(this, [[[dec, _dec5, _dec6, _dec7, _dec8], 2, "method"]], [dec, _dec, _dec2, _dec3, _dec4]));
   }
   constructor(...args) {
     _initProto(this);
@@ -22,7 +25,7 @@ class Foo {
     var _dec9, _init_bar;
     return _dec9 = this.#a, class Nested {
       static {
-        [_init_bar] = babelHelpers.applyDecs2203(this, [[_dec9, 0, "bar"]], []);
+        [_init_bar] = babelHelpers.applyDecs2203R(this, [[_dec9, 0, "bar"]], []).e;
       }
       bar = _init_bar(this);
     };
