@@ -17,6 +17,6 @@ class Foo {
 function _set_a(v) {
   _call_a(this, v);
 }
-[_call_a, _initProto] = babelHelpers.applyDecs2203(Foo, [[dec, 4, "a", function (v) {
+[_call_a, _initProto] = babelHelpers.applyDecs2203R(Foo, [[dec, 4, "a", function (v) {
   return this.value = v;
-}]], []);
+}]], []).e;
