@@ -13,9 +13,9 @@ var _a = {
   set: _set_a
 };
 (() => {
-  [_call_a, _initStatic] = babelHelpers.applyDecs2203(Foo, [[dec, 9, "a", function (v) {
+  [_call_a, _initStatic] = babelHelpers.applyDecs2203R(Foo, [[dec, 9, "a", function (v) {
     return this.value = v;
-  }]], []);
+  }]], []).e;
   _initStatic(Foo);
 })();
 babelHelpers.defineProperty(Foo, "value", 1);
