@@ -3,7 +3,7 @@ const dec = () => {};
 _computedKey = 'b';
 class Foo {
   static {
-    [_initProto] = babelHelpers.applyDecs2203(this, [[dec, 4, "a"], [dec, 4, _computedKey]], []);
+    [_initProto] = babelHelpers.applyDecs2203R(this, [[dec, 4, "a"], [dec, 4, _computedKey]], []).e;
   }
   constructor(...args) {
     _initProto(this);
