@@ -7,7 +7,7 @@ class Foo {
     });
   }
   test(other) {
-    return Object.prototype.hasOwnProperty.call(other, _foo);
+    return Object.prototype.hasOwnProperty.call(babelHelpers.checkInRHS(other), _foo);
   }
 }
 function _get_foo() {}
