@@ -3,7 +3,7 @@ class Test {
     const _Test2 = 2;
     const func = () => {
       const _Test = 3;
-      return other === Test && _Test;
+      return babelHelpers.checkInRHS(other) === Test && _Test;
     };
     return func() + _Test2;
   }
