@@ -3,7 +3,7 @@
   return _fooBrandCheck = /*#__PURE__*/new WeakSet(), class {
     #foo = void _fooBrandCheck.add(this);
     test(other) {
-      return _fooBrandCheck.has(other);
+      return _fooBrandCheck.has(babelHelpers.checkInRHS(other));
     }
   };
 })()) => {};
