@@ -3,7 +3,7 @@ function fn() {
   return new (_privBrandCheck = /*#__PURE__*/new WeakSet(), class {
     #priv = void _privBrandCheck.add(this);
     method(obj) {
-      return _privBrandCheck.has(obj);
+      return _privBrandCheck.has(babelHelpers.checkInRHS(obj));
     }
   })();
 }
