@@ -2,6 +2,6 @@ var _fooBrandCheck = /*#__PURE__*/new WeakSet();
 class Foo {
   #foo = (_fooBrandCheck.add(this), 1);
   test(other) {
-    return _fooBrandCheck.has(other);
+    return _fooBrandCheck.has(babelHelpers.checkInRHS(other));
   }
 }
