@@ -1,6 +1,6 @@
 class Foo {
   static get #foo() {}
   test(other) {
-    return Foo === other;
+    return Foo === babelHelpers.checkInRHS(other);
   }
 }
