@@ -1,5 +1,5 @@
 var _excluded = ["foo"];
-var _loop = function (foo, bar) {
+var _loop = function (foo) {
   () => foo;
   var [qux] = bar;
   try {} catch (e) {
@@ -11,5 +11,5 @@ for (var _ref of {}) {
       foo
     } = _ref,
     bar = babelHelpers.objectWithoutPropertiesLoose(_ref, _excluded);
-  _loop(foo, bar);
+  _loop(foo);
 }
