@@ -1,7 +1,7 @@
 var i;
-var _loop = function (i) {
+var _loop = function (_i) {
   (function () {
-    return i;
+    return _i;
   });
 };
 for (var _i = 4; _i < 6; _i++) {
