@@ -1,7 +1,7 @@
 function WithoutCurlyBraces() {
   var _this = this;
   if (true) {
-    var _loop = function (k) {
+    var _loop = function () {
       function foo() {
         return this;
       }
@@ -11,14 +11,14 @@ function WithoutCurlyBraces() {
       console.log(_this, k); // => undefined
     };
     for (var k in kv) {
-      _loop(k);
+      _loop();
     }
   }
 }
 function WithCurlyBraces() {
   var _this2 = this;
   if (true) {
-    var _loop2 = function (k) {
+    var _loop2 = function () {
       function foo() {
         return this;
       }
@@ -28,7 +28,7 @@ function WithCurlyBraces() {
       console.log(_this2, k); // => 777
     };
     for (var k in kv) {
-      _loop2(k);
+      _loop2();
     }
   }
 }
