@@ -1,9 +1,8 @@
-var _loop = function (_result) {
-  _result = otherValue;
+var _loop = function (result) {
+  result = otherValue;
   fn(() => {
-    _result;
+    result;
   });
-  result = _result;
 };
 var _iterator = babelHelpers.createForOfIteratorHelper(results),
   _step;
