@@ -1,9 +1,8 @@
-var _loop = function (_result) {
-  _result = otherValue;
+var _loop = function (result) {
+  result = otherValue;
   fn(() => {
-    _result;
+    result;
   });
-  result = _result;
 };
 for (var _iterator = babelHelpers.createForOfIteratorHelperLoose(results), _step; !(_step = _iterator()).done;) {
   var result = _step.value;
