@@ -1,8 +1,8 @@
 var arr = [];
 for (var i = 0; i < 10; i++) {
-  var _loop = function (i) {
+  var _loop = function (_i) {
     arr.push(function () {
-      return i;
+      return _i;
     });
   };
   for (var _i = 0; _i < 10; _i++) {
