@@ -1,7 +1,7 @@
 var a = 1;
-var _loop = function (a) {
+var _loop = function (_a) {
   items.forEach(function (item) {
-    return a;
+    return _a;
   });
 };
 for (var _a = 1; _a < 100; _a++) {
