@@ -3,5 +3,5 @@ function f() {
   babelHelpers.temporalRef(x, "x");
 }
 Math.random() === 2 && f();
-x = void 0;
+var x = void 0;
 f();
