@@ -3,5 +3,5 @@ function f() {
   babelHelpers.temporalRef(x, "x");
 }
 Math.random() === 2 && f();
-x = 3;
+var x = 3;
 expect(x).toBe(3);
