@@ -3,5 +3,4 @@ function f() {
   babelHelpers.temporalRef(x, "x");
 }
 Math.random() && f();
-x = void 0;
-void 0;
+var x = void 0;
