@@ -5,5 +5,4 @@ function f() {
   };
 }
 f();
-x = void 0;
-void 0;
+var x = void 0;
