@@ -21,4 +21,4 @@ expect(() => {
 
   // Asser that this throws, but that it's not
   // Obj.p.test's error that is thrown
-}).toThrowError(TypeError);
+}).toThrow(TypeError);
