@@ -38,4 +38,4 @@ expect(() => {
 
   // Assert that this throws, but that it's not
   // a gobbledygook error that is thrown
-}).toThrowError(TypeError);
+}).toThrow(TypeError);
