@@ -3,7 +3,7 @@
 
 import type { NodePath } from "@babel/traverse";
 import { types as t, template, type File } from "@babel/core";
-import { getDynamicImportSource } from "@babel/helper-module-transforms";
+import { buildDynamicImport } from "@babel/helper-module-transforms";
 
 const requireNoInterop = (source: t.Expression) =>
   template.expression.ast`require(${source})`;
@@ -20,19 +20,9 @@ export function transformDynamicImport(
 ) {
   const buildRequire = noInterop ? requireNoInterop : requireInterop;
 
-  const source = getDynamicImportSource(path.node);
-
-  const replacement =
-    t.isStringLiteral(source) ||
-    (t.isTemplateLiteral(source) && source.quasis.length === 0)
-      ? template.expression.ast`
-        Promise.resolve().then(() => ${buildRequire(source, file)})
-      `
-      : template.expression.ast`
-        Promise.resolve(${source}).then(
-          s => ${buildRequire(t.identifier("s"), file)}
-        )
-      `;
-
-  path.replaceWith(replacement);
+  path.replaceWith(
+    buildDynamicImport(path.node, true, false, specifier =>
+      buildRequire(specifier, file),
+    ),
+  );
 }
