@@ -17,6 +17,6 @@ expect(() => {
   // this requires helpers to be in file (not external), so they
   // are in "strict" mode code.
   obj.set();
-}).toThrow();
+}).toThrow(TypeError);
 expect(Base.test).toBe(1);
 expect(obj.test).toBe(2);
