@@ -13,6 +13,6 @@ expect(() => {
   // this requires helpers to be in file (not external), so they
   // are in "strict" mode code.
   obj.set();
-}).toThrow();
+}).toThrow(TypeError);
 expect(Base.test).toBeUndefined();
 expect(obj.test).toBeUndefined();
