@@ -1,4 +1,2 @@
 var _reactJsxRuntime = require("react/jsx-runtime");
-
-/*#__PURE__*/
-_reactJsxRuntime.jsx("div", {});
+/*#__PURE__*/_reactJsxRuntime.jsx("div", {});
