@@ -2,12 +2,10 @@ var _marked = /*#__PURE__*/babelHelpers.regeneratorRuntime().mark(fn);
 Object.keys({});
 function fn() {
   return babelHelpers.regeneratorRuntime().wrap(function fn$(_context) {
-    while (1) {
-      switch (_context.prev = _context.next) {
-        case 0:
-        case "end":
-          return _context.stop();
-      }
+    while (1) switch (_context.prev = _context.next) {
+      case 0:
+      case "end":
+        return _context.stop();
     }
   }, _marked);
 }
