@@ -4,11 +4,8 @@ class Foo {
   accessor #prop3 = 1;
   accessor [prop4] = 1;
   accessor prop5 = 1;
-  accessor prop6;
   accessor #p;
   accessor a;
   accessor aa;
-  accessor #s;
-  accessor f = 1;
   accessor g;
 }
