@@ -1,13 +1,11 @@
 function f(_ref) {
-  var _ref2 = babelHelpers.toArray(_ref);
+  var _ref2 = babelHelpers.slicedToArray(_ref, 0);
   return /*#__PURE__*/babelHelpers.regeneratorRuntime().mark(function _callee() {
     return babelHelpers.regeneratorRuntime().wrap(function _callee$(_context) {
-      while (1) {
-        switch (_context.prev = _context.next) {
-          case 0:
-          case "end":
-            return _context.stop();
-        }
+      while (1) switch (_context.prev = _context.next) {
+        case 0:
+        case "end":
+          return _context.stop();
       }
     }, _callee);
   })();
@@ -16,12 +14,10 @@ function g() {
   var x = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : fn();
   return /*#__PURE__*/babelHelpers.regeneratorRuntime().mark(function _callee2() {
     return babelHelpers.regeneratorRuntime().wrap(function _callee2$(_context2) {
-      while (1) {
-        switch (_context2.prev = _context2.next) {
-          case 0:
-          case "end":
-            return _context2.stop();
-        }
+      while (1) switch (_context2.prev = _context2.next) {
+        case 0:
+        case "end":
+          return _context2.stop();
       }
     }, _callee2);
   })();
