@@ -6,5 +6,5 @@ var _selfBrandCheck = /*#__PURE__*/new WeakSet();
 // The class declaration and the static private property should not be transpiled
 class C {
   static #self = (_selfBrandCheck.add(this), C);
-  static #_ = C.#self ?? (C.#self = _selfBrandCheck.has(C === null || C === void 0 ? void 0 : C.#self));
+  static #_ = C.#self ?? (C.#self = _selfBrandCheck.has(babelHelpers.checkInRHS(C === null || C === void 0 ? void 0 : C.#self)));
 }
