@@ -17,18 +17,16 @@ function agf() {
 function _agf() {
   _agf = babelHelpers.wrapAsyncGenerator( /*#__PURE__*/babelHelpers.regeneratorRuntime().mark(function _callee() {
     return babelHelpers.regeneratorRuntime().wrap(function _callee$(_context) {
-      while (1) {
-        switch (_context.prev = _context.next) {
-          case 0:
-            _context.next = 2;
-            return babelHelpers.awaitAsyncGenerator(1);
-          case 2:
-            _context.next = 4;
-            return 2;
-          case 4:
-          case "end":
-            return _context.stop();
-        }
+      while (1) switch (_context.prev = _context.next) {
+        case 0:
+          _context.next = 2;
+          return babelHelpers.awaitAsyncGenerator(1);
+        case 2:
+          _context.next = 4;
+          return 2;
+        case 4:
+        case "end":
+          return _context.stop();
       }
     }, _callee);
   }));
