@@ -7,4 +7,4 @@ class A {
     });
   }
 }
-register(A, _foo.has(A));
+register(A, _foo.has(babelHelpers.checkInRHS(A)));
