@@ -70,6 +70,7 @@ defineType("AssignmentExpression", {
             "ArrayPattern",
             "ObjectPattern",
             "TSAsExpression",
+            "TSSatisfiesExpression",
             "TSTypeAssertion",
             "TSNonNullExpression",
           ),
@@ -328,6 +329,7 @@ defineType("ForInStatement", {
             "ArrayPattern",
             "ObjectPattern",
             "TSAsExpression",
+            "TSSatisfiesExpression",
             "TSTypeAssertion",
             "TSNonNullExpression",
           ),
@@ -930,6 +932,7 @@ defineType("ObjectProperty", {
       "Identifier",
       "Pattern",
       "TSAsExpression",
+      "TSSatisfiesExpression",
       "TSNonNullExpression",
       "TSTypeAssertion",
     );
@@ -960,6 +963,7 @@ defineType("RestElement", {
             "ObjectPattern",
             "MemberExpression",
             "TSAsExpression",
+            "TSSatisfiesExpression",
             "TSTypeAssertion",
             "TSNonNullExpression",
           ),
@@ -1150,7 +1154,13 @@ defineType("VariableDeclaration", {
       optional: true,
     },
     kind: {
-      validate: assertOneOf("var", "let", "const"),
+      validate: assertOneOf(
+        "var",
+        "let",
+        "const",
+        // https://github.com/tc39/proposal-explicit-resource-management
+        "using",
+      ),
     },
     declarations: {
       validate: chain(
@@ -1244,6 +1254,7 @@ defineType("AssignmentPattern", {
         "ArrayPattern",
         "MemberExpression",
         "TSAsExpression",
+        "TSSatisfiesExpression",
         "TSTypeAssertion",
         "TSNonNullExpression",
       ),
@@ -1653,6 +1664,7 @@ defineType("ForOfStatement", {
           "ArrayPattern",
           "ObjectPattern",
           "TSAsExpression",
+          "TSSatisfiesExpression",
           "TSTypeAssertion",
           "TSNonNullExpression",
         );
@@ -1689,6 +1701,10 @@ defineType("ImportDeclaration", {
         assertEach(assertNodeType("ImportAttribute")),
       ),
     },
+    module: {
+      optional: true,
+      validate: assertValueType("boolean"),
+    },
     specifiers: {
       validate: chain(
         assertValueType("array"),
